explabox.expose.text 
=====================

.. automodule:: explabox.expose.text
   :members:
   :undoc-members:
   :show-inheritance:

*Submodules*:


explabox.expose.text.characters module
--------------------------------------

.. automodule:: explabox.expose.text.characters
   :members:
   :undoc-members:
   :show-inheritance:

explabox.expose.text.sentences module
-------------------------------------

.. automodule:: explabox.expose.text.sentences
   :members:
   :undoc-members:
   :show-inheritance:

explabox.expose.text.words module
---------------------------------

.. automodule:: explabox.expose.text.words
   :members:
   :undoc-members:
   :show-inheritance:
